/*
 * Copyright  2010 Nokia Corporation. All rights reserved. Nokia and
 * Nokia Connecting People are registered trademarks of Nokia Corporation.
 * Java and all Java-based marks are trademarks or registered trademarks of
 * Sun Microsystems, Inc. Other product and company names mentioned herein
 * may be trademarks or trade names of their respective owners.
 *
 * Subject to the conditions below, you may, without charge:
 *
 *   Use, copy, modify and/or merge copies of this software and associated
 *    documentation files (the Software)
 *
 *   Publish, distribute, sub-license and/or sell new software derived
 *    from or incorporating the Software.
 *
 *
 * This license, unmodified, shall be included with all copies or substantial
 * portions of the Software that are distributed in source code form.
 *
 * The Software cannot constitute the primary value of any new software
 * derived from or incorporating the Software.
 *
 * Any person dealing with the Software shall not misrepresent the source
 * of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import javax.microedition.lcdui.Display;
import javax.microedition.midlet.MIDlet;
import javax.microedition.midlet.MIDletStateChangeException;

/*
 * Ghosts sample MIDlet.
 *
 * The Ghosts mini-game demonstrates how to enable and use Nokia-specific
 * multipoint touch in LCDUI midlets.
 *
 * This is a simple game where the player should shoot a ghost by moving the crosshair
 * over the screen and firing. The crosshair is controlled by an on-screen gamepad
 * which emulates an analog stick and fire button on multipoint touch-enabled Canvas.
 *
 * Multipoint touch events are enabled by JAD attribute
 *
 *    Nokia-UI-Enhancement: EnableMultiPointTouchEvents
 *
 * To improve touch responsiveness, JAD attribute
 *
 *    Nokia-MIDlet-Tap-Detection-Options: 0, 0
 *
 * is used to disable tap detection.
 *
 * The game is implemented in following classes:
 *
 *  - Scene       - Main game logic, generates game's world-clock for rest of games classes,
 *                  passes pointer events (received though pointerPressed(), pointerDragged()
 *                  and pointerReleased() methods) to the Gamepad. Retrieves pointer number
 *                  information in method getPointerEventId().
 *
 *  - Gamepad     - Multipoint touch on-screen gamepad. Uses pointer events from Scene to
 *                  update analog stick position and fire button status.
 *
 *  - Crosshair   - Crosshair used for aiming, uses player input provided by Gamepad.
 *
 *  - Ghost       - Implements Game's non-player character behavior.
 *
 *  - Point, Size - Auxiliary classes used for position and size handling.
 *
 */
public class Ghosts extends MIDlet
{
    private Scene scene = null;
    private Display display;

    public Ghosts()
    {
        this.display = Display.getDisplay(this);
        this.scene  = new Scene(this);
        this.display.setCurrent(this.scene);
    }

    protected void destroyApp(boolean unconditional) throws MIDletStateChangeException
    {
        this.display.setCurrent(null);
        this.scene = null;
        this.display = null;
    }

    protected void pauseApp()
    {
    }

    protected void startApp() throws MIDletStateChangeException
    {
    }
}
